@@ -8,7 +8,7 @@ use XSLoader ();
 our ($VERSION);
 
 BEGIN {
-    $VERSION = '0.28_01';
+    $VERSION = '0.29_01';
     XSLoader::load( __PACKAGE__, $VERSION );
 }
 
@@ -18,6 +18,12 @@ BEGIN {
 
 DNS::Unbound - Query DNS recursively via L<libunbound|https://www.nlnetlabs.nl/documentation/unbound/libunbound/>
 
+=begin html
+
+<a href='https://coveralls.io/github/FGasper/p5-DNS-Unbound?branch=master'><img src='https://coveralls.io/repos/github/FGasper/p5-DNS-Unbound/badge.svg?branch=master' alt='Coverage Status' /></a>
+
+=end html
+
 =head1 SYNOPSIS
 
     my $dns = DNS::Unbound->new()->set_option( verbosity => 2 );
@@ -57,12 +63,6 @@ You can also integrate with a custom event loop; see L</"EVENT LOOPS"> below.
 
 =head1 DESCRIPTION
 
-=begin html
-
-<a href='https://coveralls.io/github/FGasper/p5-DNS-Unbound?branch=master'><img src='https://coveralls.io/repos/github/FGasper/p5-DNS-Unbound/badge.svg?branch=master' alt='Coverage Status' /></a>
-
-=end html
-
 Typical DNS lookups involve a request to a local server that caches
 information from DNS. The caching makes it fast, but it also means
 updates to DNS aren’t always available via that local server right away.
@@ -111,7 +111,8 @@ e.g., invalid inputs.
 Unbound gives an error.
 
 =item * L<DNS::Unbound::X::ResolveError> instances. A subclass
-of the last kind, for resolution failures.
+of the last kind, for (Unbound-reported) resolution failures.
+(This is B<NOT> for DNS-reported failures.)
 
 =back
 
